@@ -205,16 +205,12 @@ class CfnFileSystem(
         subnet_ids: typing.List[str],
         backup_id: typing.Optional[str] = None,
         kms_key_id: typing.Optional[str] = None,
-        lustre_configuration: typing.Optional[
-            typing.Union["LustreConfigurationProperty", aws_cdk.core.IResolvable]
-        ] = None,
+        lustre_configuration: typing.Optional[typing.Union["LustreConfigurationProperty", aws_cdk.core.IResolvable]] = None,
         security_group_ids: typing.Optional[typing.List[str]] = None,
         storage_capacity: typing.Optional[jsii.Number] = None,
         storage_type: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
-        windows_configuration: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "WindowsConfigurationProperty"]
-        ] = None,
+        windows_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WindowsConfigurationProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::FSx::FileSystem``.
 
@@ -356,9 +352,7 @@ class CfnFileSystem(
     @jsii.member(jsii_name="lustreConfiguration")
     def lustre_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["LustreConfigurationProperty", aws_cdk.core.IResolvable]
-    ]:
+    ) -> typing.Optional[typing.Union["LustreConfigurationProperty", aws_cdk.core.IResolvable]]:
         """``AWS::FSx::FileSystem.LustreConfiguration``.
 
         see
@@ -369,9 +363,7 @@ class CfnFileSystem(
     @lustre_configuration.setter
     def lustre_configuration(
         self,
-        value: typing.Optional[
-            typing.Union["LustreConfigurationProperty", aws_cdk.core.IResolvable]
-        ],
+        value: typing.Optional[typing.Union["LustreConfigurationProperty", aws_cdk.core.IResolvable]],
     ) -> None:
         jsii.set(self, "lustreConfiguration", value)
 
@@ -421,9 +413,7 @@ class CfnFileSystem(
     @jsii.member(jsii_name="windowsConfiguration")
     def windows_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "WindowsConfigurationProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WindowsConfigurationProperty"]]:
         """``AWS::FSx::FileSystem.WindowsConfiguration``.
 
         see
@@ -434,9 +424,7 @@ class CfnFileSystem(
     @windows_configuration.setter
     def windows_configuration(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "WindowsConfigurationProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WindowsConfigurationProperty"]],
     ) -> None:
         jsii.set(self, "windowsConfiguration", value)
 
@@ -462,9 +450,7 @@ class CfnFileSystem(
             *,
             auto_import_policy: typing.Optional[str] = None,
             automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
-            copy_tags_to_backups: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            copy_tags_to_backups: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
             daily_automatic_backup_start_time: typing.Optional[str] = None,
             deployment_type: typing.Optional[str] = None,
             export_path: typing.Optional[str] = None,
@@ -492,15 +478,11 @@ class CfnFileSystem(
             if auto_import_policy is not None:
                 self._values["auto_import_policy"] = auto_import_policy
             if automatic_backup_retention_days is not None:
-                self._values[
-                    "automatic_backup_retention_days"
-                ] = automatic_backup_retention_days
+                self._values["automatic_backup_retention_days"] = automatic_backup_retention_days
             if copy_tags_to_backups is not None:
                 self._values["copy_tags_to_backups"] = copy_tags_to_backups
             if daily_automatic_backup_start_time is not None:
-                self._values[
-                    "daily_automatic_backup_start_time"
-                ] = daily_automatic_backup_start_time
+                self._values["daily_automatic_backup_start_time"] = daily_automatic_backup_start_time
             if deployment_type is not None:
                 self._values["deployment_type"] = deployment_type
             if export_path is not None:
@@ -510,13 +492,9 @@ class CfnFileSystem(
             if import_path is not None:
                 self._values["import_path"] = import_path
             if per_unit_storage_throughput is not None:
-                self._values[
-                    "per_unit_storage_throughput"
-                ] = per_unit_storage_throughput
+                self._values["per_unit_storage_throughput"] = per_unit_storage_throughput
             if weekly_maintenance_start_time is not None:
-                self._values[
-                    "weekly_maintenance_start_time"
-                ] = weekly_maintenance_start_time
+                self._values["weekly_maintenance_start_time"] = weekly_maintenance_start_time
 
         @builtins.property
         def auto_import_policy(self) -> typing.Optional[str]:
@@ -661,13 +639,9 @@ class CfnFileSystem(
             if domain_name is not None:
                 self._values["domain_name"] = domain_name
             if file_system_administrators_group is not None:
-                self._values[
-                    "file_system_administrators_group"
-                ] = file_system_administrators_group
+                self._values["file_system_administrators_group"] = file_system_administrators_group
             if organizational_unit_distinguished_name is not None:
-                self._values[
-                    "organizational_unit_distinguished_name"
-                ] = organizational_unit_distinguished_name
+                self._values["organizational_unit_distinguished_name"] = organizational_unit_distinguished_name
             if password is not None:
                 self._values["password"] = password
             if user_name is not None:
@@ -759,18 +733,11 @@ class CfnFileSystem(
             *,
             active_directory_id: typing.Optional[str] = None,
             automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
-            copy_tags_to_backups: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            copy_tags_to_backups: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
             daily_automatic_backup_start_time: typing.Optional[str] = None,
             deployment_type: typing.Optional[str] = None,
             preferred_subnet_id: typing.Optional[str] = None,
-            self_managed_active_directory_configuration: typing.Optional[
-                typing.Union[
-                    aws_cdk.core.IResolvable,
-                    "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty",
-                ]
-            ] = None,
+            self_managed_active_directory_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty"]] = None,
             throughput_capacity: typing.Optional[jsii.Number] = None,
             weekly_maintenance_start_time: typing.Optional[str] = None,
         ) -> None:
@@ -792,29 +759,21 @@ class CfnFileSystem(
             if active_directory_id is not None:
                 self._values["active_directory_id"] = active_directory_id
             if automatic_backup_retention_days is not None:
-                self._values[
-                    "automatic_backup_retention_days"
-                ] = automatic_backup_retention_days
+                self._values["automatic_backup_retention_days"] = automatic_backup_retention_days
             if copy_tags_to_backups is not None:
                 self._values["copy_tags_to_backups"] = copy_tags_to_backups
             if daily_automatic_backup_start_time is not None:
-                self._values[
-                    "daily_automatic_backup_start_time"
-                ] = daily_automatic_backup_start_time
+                self._values["daily_automatic_backup_start_time"] = daily_automatic_backup_start_time
             if deployment_type is not None:
                 self._values["deployment_type"] = deployment_type
             if preferred_subnet_id is not None:
                 self._values["preferred_subnet_id"] = preferred_subnet_id
             if self_managed_active_directory_configuration is not None:
-                self._values[
-                    "self_managed_active_directory_configuration"
-                ] = self_managed_active_directory_configuration
+                self._values["self_managed_active_directory_configuration"] = self_managed_active_directory_configuration
             if throughput_capacity is not None:
                 self._values["throughput_capacity"] = throughput_capacity
             if weekly_maintenance_start_time is not None:
-                self._values[
-                    "weekly_maintenance_start_time"
-                ] = weekly_maintenance_start_time
+                self._values["weekly_maintenance_start_time"] = weekly_maintenance_start_time
 
         @builtins.property
         def active_directory_id(self) -> typing.Optional[str]:
@@ -875,12 +834,7 @@ class CfnFileSystem(
         @builtins.property
         def self_managed_active_directory_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty",
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty"]]:
             """``CfnFileSystem.WindowsConfigurationProperty.SelfManagedActiveDirectoryConfiguration``.
 
             see
@@ -942,20 +896,12 @@ class CfnFileSystemProps:
         subnet_ids: typing.List[str],
         backup_id: typing.Optional[str] = None,
         kms_key_id: typing.Optional[str] = None,
-        lustre_configuration: typing.Optional[
-            typing.Union[
-                "CfnFileSystem.LustreConfigurationProperty", aws_cdk.core.IResolvable
-            ]
-        ] = None,
+        lustre_configuration: typing.Optional[typing.Union["CfnFileSystem.LustreConfigurationProperty", aws_cdk.core.IResolvable]] = None,
         security_group_ids: typing.Optional[typing.List[str]] = None,
         storage_capacity: typing.Optional[jsii.Number] = None,
         storage_type: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
-        windows_configuration: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnFileSystem.WindowsConfigurationProperty"
-            ]
-        ] = None,
+        windows_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.WindowsConfigurationProperty"]] = None,
     ) -> None:
         """Properties for defining a ``AWS::FSx::FileSystem``.
 
@@ -1033,11 +979,7 @@ class CfnFileSystemProps:
     @builtins.property
     def lustre_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnFileSystem.LustreConfigurationProperty", aws_cdk.core.IResolvable
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnFileSystem.LustreConfigurationProperty", aws_cdk.core.IResolvable]]:
         """``AWS::FSx::FileSystem.LustreConfiguration``.
 
         see
@@ -1084,11 +1026,7 @@ class CfnFileSystemProps:
     @builtins.property
     def windows_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable, "CfnFileSystem.WindowsConfigurationProperty"
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.WindowsConfigurationProperty"]]:
         """``AWS::FSx::FileSystem.WindowsConfiguration``.
 
         see
@@ -1392,9 +1330,7 @@ class LustreConfiguration:
         if per_unit_storage_throughput is not None:
             self._values["per_unit_storage_throughput"] = per_unit_storage_throughput
         if weekly_maintenance_start_time is not None:
-            self._values[
-                "weekly_maintenance_start_time"
-            ] = weekly_maintenance_start_time
+            self._values["weekly_maintenance_start_time"] = weekly_maintenance_start_time
 
     @builtins.property
     def deployment_type(self) -> "LustreDeploymentType":
